@@ -9,26 +9,19 @@ package Bot;
 use base qw(Bot::BasicBot);
 use warnings;
 use strict;
-use URI::Title;
+use URI::Title qw( title );
+use URI::Find::Simple qw( list_uris );
 
 sub said {
   my $self = shift;
   my $message = shift;
   my $body = $message->{body};
-  return unless my @urls = find_urls($message->{body});
+  return unless my @urls = list_uris($message->{body});
   $self->reply($message, title($_)) for (@urls);
 }
 
-# this function could be _so_ much smarter.
-sub find_urls {
-  my $text = shift;
-  return ($1) if ($text =~ m!(http://\S+)!);
-  return undef;
-}
-
-package main;
-
 Bot->new(
+  server => "irc.perl.org",
   channels => [ '#jerakeen' ],
   nick => 'namer',
 )->run();
