@@ -1,6 +1,6 @@
 package Bot::BasicBot;
 our $AUTHORITY = 'cpan:BIGPRESH';
-$Bot::BasicBot::VERSION = '0.91';
+$Bot::BasicBot::VERSION = '0.92';
 use strict;
 use warnings;
 
@@ -68,6 +68,7 @@ sub run {
                 irc_kick         => "irc_kicked_state",
                 irc_nick         => "irc_nick_state",
                 irc_quit         => "irc_quit_state",
+                irc_mode         => "irc_mode_state",
 
                 fork_close       => "fork_close_state",
                 fork_error       => "fork_error_state",
@@ -117,6 +118,8 @@ sub topic { return }
 
 sub nick_change { return }
 
+sub mode_change { return }
+
 sub kicked { return }
 
 sub tick { return 0; }
@@ -549,9 +552,11 @@ sub irc_001_state {
         $self->charset_encode($self->nick),
     );
 
+    $self->log("Connected to " . $self->server);
+
     # connect to the channel
     for my $channel ($self->channels) {
-        $self->log("Trying to connect to '$channel'\n");
+        $self->log("Trying to join '$channel'\n");
         $kernel->post(
             $self->{IRCNAME},
             'join',
@@ -604,6 +609,20 @@ sub irc_nick_state {
     return;
 }
 
+sub irc_mode_state {
+    my ($self, $nick, $channel, $mode_changes) = @_[OBJECT, ARG0, ARG1, ARG2];
+    my @mode_operands = @_[ARG3..$#_];
+    $self->mode_change(
+        {
+            channel       => $channel,
+            who           => $nick,
+            mode_changes  => $mode_changes,
+            mode_operands => \@mode_operands,
+        }
+    );
+    return;
+}
+
 sub irc_quit_state {
     my ($self, $kernel, $session) = @_[OBJECT, KERNEL, SESSION];
     my ($nick, $message) = @_[ARG0..$#_];
@@ -1125,6 +1144,19 @@ topic of the channel.
 When a user changes nicks, this will be called. It receives two arguments:
 the old nickname and the new nickname.
 
+=head2 C<mode_change>
+
+When a user sets channel modes, or the bot (or someone sharing its bouncer
+connection?) sets user modes, this will be called.  It receives a hashref
+which will look like the following:
+
+  {
+      channel => "#channel",
+      who => "nick!user@host",
+      mode_changes => "+o+v",
+      mode_operands => ["bigpresh", "somedude"],
+  }
+
 =head2 C<kicked>
 
 Called when a user is kicked from the channel. It receives a hashref which
@@ -1175,6 +1207,15 @@ Receives a hashref which will look like:
       body => "quit message",
     }
 
+=head2 C<irc_raw>
+
+Receives a line of raw IRC input.  Intended for cases where you're trying to do
+something clever which the normal methods and parsing supplied can't handle.
+
+=head2 C<irc_raw_out>
+
+Receives a line of raw IRC output being sent to the IRC server.
+
 =head1 BOT METHODS
 
 There are a few methods you can call on the bot object to do things. These
@@ -1491,7 +1532,10 @@ If you have any questions or issues, you can drop by in #poe or
 
 =head1 AUTHOR
 
-Tom Insam E<lt>tom@jerakeen.orgE<gt>
+David Precious (BIGPRESH) C<< <davidp@preshweb.co.uk> >> is the 
+current maintainer.
+
+Tom Insam E<lt>tom@jerakeen.orgE<gt> was the original author.
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
@@ -1521,7 +1565,11 @@ In April 2017, maintainership moved to David Precious
 
 =head1 SEE ALSO
 
-L<POE>, L<POE::Component::IRC>
+If you want to write/run a more flexible bot which supports module loading,
+authentication, data storage etc, consider the subclass
+L<Bot::BasicBot::Pluggable>.
+
+Also see L<POE>, L<POE::Component::IRC>
 
 Possibly Infobot, at http://www.infobot.org
 
